/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package nl.cloudfarming.client.planning.tactical;

import java.beans.IntrospectionException;
import java.util.List;
import nl.cloudfarming.client.model.Culture;
import nl.cloudfarming.client.model.FieldPlan;
import nl.cloudfarming.client.planning.PlanEventKey;
import nl.cloudfarming.eventbus.GuiEvent;
import nl.cloudfarming.eventbus.GuiEventBus;
import nl.cloudfarming.eventbus.GuiEventKey;
import nl.cloudfarming.eventbus.GuiEventListener;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Node;
import org.openide.util.Exceptions;

/**
 *
 * @author Timon Veenstra
 */
public class CultureNodeFactory extends ChildFactory<Culture>{

    private final FieldPlan fieldPlan;

    public CultureNodeFactory(FieldPlan fieldPlan) {
        this.fieldPlan = fieldPlan;
        GuiEventBus.addListener(new GuiEventListener() {

            @Override
            public void onEvent(GuiEvent event) {
                refresh(true);
            }

            @Override
            public boolean listensTo(GuiEventKey guiEventKey) {
                return PlanEventKey.NEW_CULTURE.equals(guiEventKey);
            }

            @Override
            public String getModuleName() {
                return TacticalPlanningModule.MODULE_NAME;
            }
        });
    }

    @Override
    protected Node createNodeForKey(Culture key) {
        try {
            return new CultureNode(key);
        } catch (IntrospectionException ex) {
            Exceptions.printStackTrace(ex);
            return null;
        }
    }



    @Override
    protected boolean createKeys(List<Culture> toPopulate) {
        toPopulate.addAll(fieldPlan.getCultures());
        return true;
    }

    
}
